@@ -1,9 +1,9 @@
 package WebService::LastFM::TrackInfo;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Access to the track.getInfo slice of the LastFM API
+# ABSTRACT: Access to *.getInfo slices of the last.fm API
 
-our $VERSION = '0.0204';
+our $VERSION = '0.0205';
 
 use Moo;
 use strictures 2;
@@ -24,7 +24,7 @@ has api_key => (
 
 has method => (
     is      => 'ro',
-    default => sub { 'track.getInfo' },
+    default => sub { 'track' },
 );
 
 
@@ -56,15 +56,15 @@ sub fetch {
     my ( $self, %args ) = @_;
 
     croak 'No artist provided' unless $args{artist};
-    croak 'No track provided' if $self->method eq 'track.getInfo' && !$args{track};
-    croak 'No album provided' if $self->method eq 'album.getInfo' && !$args{album};
+    croak 'No track provided' if $self->method eq 'track' && !$args{track};
+    croak 'No album provided' if $self->method eq 'album' && !$args{album};
 
     my $url = Mojo::URL->new($self->base)
         ->path($self->version)
         ->query(
             %args,
             api_key => $self->api_key,
-            method  => $self->method,
+            method  => $self->method . '.getInfo',
             format  => $self->format,
         );
 
@@ -114,11 +114,11 @@ __END__
 
 =head1 NAME
 
-WebService::LastFM::TrackInfo - Access to the track.getInfo slice of the LastFM API
+WebService::LastFM::TrackInfo - Access to *.getInfo slices of the last.fm API
 
 =head1 VERSION
 
-version 0.0204
+version 0.0205
 
 =head1 SYNOPSIS
 
@@ -133,7 +133,7 @@ version 0.0204
 
   $w = WebService::LastFM::TrackInfo->new(
     api_key => 'abcdef123456',
-    method  => 'album.getInfo',
+    method  => 'album',
   );
   $r = $w->fetch(
     artist => 'Led Zeppelin',
@@ -142,11 +142,8 @@ version 0.0204
 
 =head1 DESCRIPTION
 
-C<WebService::LastFM::TrackInfo> provides access to the
-L<https://www.last.fm/api/show/track.getInfo> API slice.
-
-This module may also be used to get information about other bits of
-the API, like artist or album, for example.
+C<WebService::LastFM::TrackInfo> provides access to a couple *.getInfo
+API slices: track, artist and album.
 
 =head1 ATTRIBUTES
 
@@ -158,10 +155,9 @@ Default: C<undef>
 
 =head2 method
 
-The required, last.fm API method string ("track.getInfo",
-"artist.getInfo", or "album.getInfo").
+The required method string ("track", "artist", or "album").
 
-Default: C<track.getInfo>
+Default: C<track>
 
 =head2 format
 
@@ -203,10 +199,10 @@ required B<api_key> argument.
 =head2 fetch
 
   $r = $w->fetch(artist => $artist, track => $track);
-  $r = $w->fetch(artist => $artist, album => $album); # for method => album.getInfo
-  $r = $w->fetch(artist => $artist); # for method => artist.getInfo
+  $r = $w->fetch(artist => $artist, album => $album); # for method => album
+  $r = $w->fetch(artist => $artist); # for method => artist
 
-Fetch the results given the B<artist> and B<track> arguments.
+Fetch the results given the B<artist>, B<album> or B<track>.
 
 =head1 SEE ALSO
 
